@@ -13,7 +13,6 @@ parameterWeights <-  matrix(1, nrow = length(levels(sampleGrouping)), ncol = nco
 alpha <- 0.5
 d <- 20L
 lambda.min <- 0.5
-algorithm.config <- sgl.standard.config 
 
 # indices
 test <- replicate(2, 1:20, simplify = FALSE)
@@ -21,8 +20,8 @@ train <- lapply(test, function(s) (1:nrow(x))[-s])
 
 # create data
 data <- create.sgldata(x, y, weights, sampleGrouping)
-lambda <- sgl_lambda_sequence("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha = alpha, d = d, lambda.min, algorithm.config)
-fit1a.sub <- sgl_subsampling("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, train, test, max.threads = 1L, algorithm.config)
+lambda <- sgl_lambda_sequence("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha = alpha, d = d, lambda.min)
+fit1a.sub <- sgl_subsampling("sgl_test_dense", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, train, test, max.threads = 1L)
 
 data <- create.sgldata(x, y, weights, sampleGrouping, sparseX = TRUE)
-fit1b.sub <- sgl_subsampling("sgl_test_sparse", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, train, test, max.threads = 1L, algorithm.config)
+fit1b.sub <- sgl_subsampling("sgl_test_sparse", "sglOptim", data, covariateGrouping, groupWeights, parameterWeights, alpha, lambda, train, test, max.threads = 1L)
